Module an_err

Module an_err 

Structs

AnErr
A compact, Copy, zero-allocation error type that records a parallel stack of error kinds, source locations, and per-level human-readable reasons.
TraceIter
Iterator over the error trace levels of an AnErr.
WireErr
Fully portable, zero-allocation error for transmission/reception.
WireLocation
Portable location for wire transmission.