BopData

Struct BopData 

pub struct BopData { /* private fields */ }
Container for Body Orientation Parameters data.

  • On Earth this would enable time scale conversions to and from the UT1 time scale.
  • Earth Orientation Parameters data is available from: https://maia.usno.navy.mil/ser7/finals2000A.all

Implementations

Source

impl BopData

pub fn data_from_reader<R: BufRead>( reader: R, format: BopFormat, separator: Separator, ) -> Result<Vec<BopDataRow>, DtErr>

pub fn data_from_text_file<P: AsRef<Path>>( path: P, format: BopFormat, separator: Separator, ) -> Result<Vec<BopDataRow>, DtErr>

pub fn from_text_file<P: AsRef<Path>>( path: P, format: BopFormat, separator: Separator, ) -> Result<Self, DtErr>

Source

impl BopData

pub const MAX_LINE_LEN: usize = 8192

pub fn data_from_str( s: &str, format: BopFormat, separator: Separator, ) -> Result<Vec<BopDataRow>, DtErr>

pub fn data_from_bytes( bytes: &[u8], format: BopFormat, separator: Separator, ) -> Result<Vec<BopDataRow>, DtErr>

pub fn from_str( s: &str, format: BopFormat, separator: Separator, ) -> Result<Self, DtErr>

pub fn from_bytes( bytes: &[u8], format: BopFormat, separator: Separator, ) -> Result<Self, DtErr>

pub fn params(&self, mjd: Real) -> Option<BopParams>

Returns all interpolated orientation parameters (offset + polar motion) at the given MJD.

Returns None if the table is empty or the MJD is completely outside the loaded data.