AsciiStrError

Enum AsciiStrError 

pub enum AsciiStrError {
    InvalidAscii,
    TooLong {
        capacity: usize,
        length: usize,
    },
    CorruptedData,
}
Errors returned by AsciiStr operations.

Variants



InvalidAscii

Input contained non-ASCII characters.



TooLong

Input exceeded the fixed capacity N.

Fields

capacity: usize

Maximum capacity of this AsciiStr.

length: usize

Length of the rejected input.



CorruptedData

Internal data is corrupted or violates the type invariant.

This can occur when:

  • The bytes are not valid UTF-8 (should never happen for ASCII data).
  • Non-zero bytes appear after the first nul byte (violates the “nul-terminated + trailing zeros” representation invariant).

This variant exists only to keep the public API 100% panic-free. It is unreachable when the type is constructed through the safe API.