Lang

Enum Lang 

#[non_exhaustive]
pub enum Lang {
Show 184 variants En, Aa, Ab, Ae, Af, Ak, Am, An, Ar, As, Av, Ay, Az, Ba, Be, Bg, Bh, Bi, Bm, Bn, Bo, Br, Bs, Ca, Ce, Ch, Co, Cr, Cs, Cu, Cv, Cy, Da, De, Dv, Dz, Ee, El, Eo, Es, Et, Eu, Fa, Ff, Fi, Fj, Fo, Fr, Fy, Ga, Gd, Gl, Gn, Gu, Gv, Ha, He, Hi, Ho, Hr, Ht, Hu, Hy, Hz, Ia, Id, Ie, Ig, Ii, Ik, Io, Is, It, Iu, Ja, Jv, Ka, Kg, Ki, Kj, Kk, Kl, Km, Kn, Ko, Kr, Ks, Ku, Kv, Kw, Ky, La, Lb, Lg, Li, Ln, Lo, Lt, Lu, Lv, Mg, Mh, Mi, Mk, Ml, Mn, Mr, Ms, Mt, My, Na, Nb, Nd, Ne, Ng, Nl, Nn, No, Nr, Nv, Ny, Oc, Oj, Om, Or, Os, Pa, Pi, Pl, Ps, Pt, Qu, Rm, Rn, Ro, Ru, Rw, Sa, Sc, Sd, Se, Sg, Si, Sk, Sl, Sm, Sn, So, Sq, Sr, Ss, St, Su, Sv, Sw, Ta, Te, Tg, Th, Ti, Tk, Tl, Tn, To, Tr, Ts, Tt, Tw, Ty, Ug, Uk, Ur, Uz, Ve, Vi, Vo, Wa, Wo, Xh, Yi, Yo, Za, Zh, Zu,
}
Language codes following ISO 639-1 standard (two-letter codes). Default is En (English)

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


En

English (default)



Aa

Afar



Ab

Abkhazian



Ae

Avestan



Af

Afrikaans



Ak

Akan



Am

Amharic



An

Aragonese



Ar

Arabic



As

Assamese



Av

Avaric



Ay

Aymara



Az

Azerbaijani



Ba

Bashkir



Be

Belarusian



Bg

Bulgarian



Bh

Bihari languages



Bi

Bislama



Bm

Bambara



Bn

Bengali



Bo

Tibetan



Br

Breton



Bs

Bosnian



Ca

Catalan



Ce

Chechen



Ch

Chamorro



Co

Corsican



Cr

Cree



Cs

Czech



Cu

Church Slavic



Cv

Chuvash



Cy

Welsh



Da

Danish



De

German



Dv

Divehi



Dz

Dzongkha



Ee

Ewe



El

Greek



Eo

Esperanto



Es

Spanish



Et

Estonian



Eu

Basque



Fa

Persian



Ff

Fulah



Fi

Finnish



Fj

Fijian



Fo

Faroese



Fr

French



Fy

Western Frisian



Ga

Irish



Gd

Scottish Gaelic



Gl

Galician



Gn

Guarani



Gu

Gujarati



Gv

Manx



Ha

Hausa



He

Hebrew



Hi

Hindi



Ho

Hiri Motu



Hr

Croatian



Ht

Haitian Creole



Hu

Hungarian



Hy

Armenian



Hz

Herero



Ia

Interlingua



Id

Indonesian



Ie

Interlingue



Ig

Igbo



Ii

Sichuan Yi



Ik

Inupiaq



Io

Ido



Is

Icelandic



It

Italian



Iu

Inuktitut



Ja

Japanese



Jv

Javanese



Ka

Georgian



Kg

Kongo



Ki

Kikuyu



Kj

Kuanyama



Kk

Kazakh



Kl

Greenlandic



Km

Khmer



Kn

Kannada



Ko

Korean



Kr

Kanuri



Ks

Kashmiri



Ku

Kurdish



Kv

Komi



Kw

Cornish



Ky

Kyrgyz



La

Latin



Lb

Luxembourgish



Lg

Ganda



Li

Limburgish



Ln

Lingala



Lo

Lao



Lt

Lithuanian



Lu

Luba-Katanga



Lv

Latvian



Mg

Malagasy



Mh

Marshallese



Mi

Maori



Mk

Macedonian



Ml

Malayalam



Mn

Mongolian



Mr

Marathi



Ms

Malay



Mt

Maltese



My

Burmese



Na

Nauru



Nb

Norwegian Bokmål



Nd

North Ndebele



Ne

Nepali



Ng

Ndonga



Nl

Dutch



Nn

Norwegian Nynorsk



No

Norwegian



Nr

South Ndebele



Nv

Navajo



Ny

Chichewa



Oc

Occitan



Oj

Ojibwa



Om

Oromo



Or

Oriya



Os

Ossetian



Pa

Punjabi



Pi

Pali



Pl

Polish



Ps

Pashto



Pt

Portuguese



Qu

Quechua



Rm

Romansh



Rn

Rundi



Ro

Romanian



Ru

Russian



Rw

Kinyarwanda



Sa

Sanskrit



Sc

Sardinian



Sd

Sindhi



Se

Northern Sami



Sg

Sango



Si

Sinhala



Sk

Slovak



Sl

Slovenian



Sm

Samoan



Sn

Shona



So

Somali



Sq

Albanian



Sr

Serbian



Ss

Swati



St

Southern Sotho



Su

Sundanese



Sv

Swedish



Sw

Swahili



Ta

Tamil



Te

Telugu



Tg

Tajik



Th

Thai



Ti

Tigrinya



Tk

Turkmen



Tl

Tagalog



Tn

Tswana



To

Tonga



Tr

Turkish



Ts

Tsonga



Tt

Tatar



Tw

Twi



Ty

Tahitian



Ug

Uyghur



Uk

Ukrainian



Ur

Urdu



Uz

Uzbek



Ve

Venda



Vi

Vietnamese



Vo

Volapük



Wa

Walloon



Wo

Wolof



Xh

Xhosa



Yi

Yiddish



Yo

Yoruba



Za

Zhuang



Zh

Chinese



Zu

Zulu