pub enum EopFormat {
Finals2000A,
C04,
Custom(CustomEopCols),
}Expand description
Body Orientation Parameters Format.
Formats to provide to the parser, including a custom one to allow specific column indices.
Finals2000Asuch as is available from https://maia.usno.navy.mil/ser7/finals2000A.allC04such as is available from https://datacenter.iers.org/data/latestVersion/EOP_20u24_C04_one_file_1962-now.txtCustomso you can provide your own specific column indices usingCustomEopCols.
Variants
Finals2000A
finals2000A.all / finals.all.iau2000.txt style files
C04
C04 long-term series
Custom(CustomEopCols)
User-defined column indices (0-based)