GregorianTime

Struct GregorianTime 

pub struct GregorianTime { /* private fields */ }
UTC Civil calendar and time-of-day components of a Dt.

Implementations

Source

impl GregorianTime

pub fn to_ascii_str(&self, fmt: &str) -> Result<AsciiStr<STRFTIME_SIZE>, DtErr>

No-allocation formatting.

Source

impl GregorianTime

pub const fn new( unix_attosec: i128, yr: i64, mo: u8, day: u8, hr: u8, min: u8, sec: u8, attos: u64, iso_yr: i64, iso_wk: u8, iso_wkday: Weekday, day_of_yr: u16, wkday: u8, wk_of_yr_sun: u8, wk_of_yr_mon: u8, ) -> Self

Creates a new GregorianTime with all fields specified. This isn’t the recommended way to make a GregorianTime. It’s safer to use Dt::to_gregorian_time().

pub const fn unix_attosec(&self) -> i128

UNIX attoseconds since 1970 epoch

pub const fn unix_timestamp(&self) -> (i64, u64)

Returns the Unix timestamp since 1970-01-01 00:00:00 UTC as a tuple of (whole_seconds, attoseconds).

  • whole_seconds can be negative (for dates before 1970).
  • The fractional part (attoseconds) is always in the range 0..=999_999_999_999_999_999.
pub const fn yr(&self) -> i64

Gregorian year (proleptic Gregorian calendar, supports negative years and year 0).

pub const fn mo(&self) -> u8

Gregorian month in the range [1, 12].

pub const fn day(&self) -> u8

Gregorian day of the month in the range [1, 31].

pub const fn hr(&self) -> u8

Hour of the day in the range [0, 23].

pub const fn min(&self) -> u8

Minute in the range [0, 59].

pub const fn sec(&self) -> u8

Second in the range [0, 60] (60 only during UTC leap seconds).

pub const fn attos(&self) -> u64

Fractional part of the second expressed in attoseconds (0 ≤ attos < 10¹⁸).

pub const fn iso_yr(&self) -> i64

ISO 8601 week year.

pub const fn iso_wk(&self) -> u8

ISO 8601 week number in the range [1, 53].

pub const fn iso_wkday(&self) -> Weekday

ISO 8601 weekday (Monday-based Weekday enum).

pub const fn day_of_yr(&self) -> u16

Ordinal day of the year (1-based).

pub const fn wkday_sun(&self) -> u8

Weekday number (0 = Sunday … 6 = Saturday).

pub const fn wkday_mon(&self) -> u8

ISO 8601 weekday (0 = Monday … 6 = Sunday).

pub const fn wk_of_yr_sun(&self) -> u8

Sunday based week of year (Range: 0..=53).

pub const fn wk_of_yr_mon(&self) -> u8

Monday based week of year (Range: 0..=53).

pub const fn offset_sec(&self) -> Option<i32>

pub const fn tz(&self) -> Option<&AsciiStr<50>>

pub const fn tz_abbrev(&self) -> Option<&AsciiStr<29>>

pub const fn to_time_point(self) -> Dt

Reconstructs a Dt from these UTC civil components.

Round-tripping with Dt::to_gregorian_time.