pub struct LiteStr<const N: usize> { /* private fields */ }Expand description
Fixed-capacity, stack-only UTF-8 string stored in a single [u8; N] array.
- The string is stored as raw bytes with C-style nul termination.
- Its logical length is determined at runtime by the position of the first nul byte (
b'\0'). - All bytes after the string content are guaranteed to be zero.
- The type guarantees that the prefix up to the first nul is always valid UTF-8 (when constructed through the safe API).
- This type is intentionally kept very lightweight. When you use different sizes
(such as
LiteStr<16>,LiteStr<32>,LiteStr<64>), Rust creates a full separate copy of the type and all of its methods for each size. This is why it is important to keep the implementation ofLiteStras minimal as possible.
Implementations
Sourceimpl<const N: usize> LiteStr<N>
impl<const N: usize> LiteStr<N>
pub const SIZE: usize = N
Sourcepub fn new(s: &str) -> Self
pub fn new(s: &str) -> Self
Recommended ergonomic constructor – truncates at a UTF-8 boundary if necessary.
Sourcepub fn as_str(&self) -> Result<&str, LiteStrErr>
pub fn as_str(&self) -> Result<&str, LiteStrErr>
Returns the stored string as &str.
pub fn from_bytes(bytes: &[u8]) -> Result<Self, LiteStrErr>
pub fn to_bytes(&self) -> [u8; N]