YmdHms

Struct YmdHms 

pub struct YmdHms { /* private fields */ }
Combined Gregorian date + wall time with subsecond precision.

Has some basic calendar aware math, but not time zone aware.

Examples

Creating a YmdHms.

use deep_time::{Dt, Scale};

// clamped to 29
let x = Dt::from_ymd(2000, 2, 30).to_ymdhms(Scale::TAI);

assert_eq!(x.day(), 29);

Adding a year. 2000 is a leap year and Feb. 29th is possible, but 2001 isn’t a leap year so the day is clamped to the 28th.

use deep_time::{Dt, Scale};

let x = Dt::from_ymd(2000, 2, 29).to_ymdhms(Scale::TAI);
let x = x.add_yr(1);

assert_eq!(x.day(), 28);

Implementations

Source

impl YmdHms

pub const fn to_dt(&self) -> Dt

Reconstructs a Dt.

pub const fn add_yr(&self, years: i64) -> Self

Adds (or subtracts) whole years, preserving month and day-of-month. Negative values subtract years. Uses standard last-day-of-month clamping.

pub const fn add_mo(&self, months: i64) -> Self

Adds (or subtracts) whole months. Negative values subtract months. Uses i128 total-month arithmetic to avoid overflow at extreme years.

pub const fn add_days(&self, days: i64) -> Self

Adds (or subtracts) calendar days using Julian Day arithmetic. Negative values subtract days.

pub const fn add_wk(&self, weeks: i64) -> Self

pub const fn add_attos(&self, attos: i128) -> Self

pub const fn add_sec(&self, sec: i64) -> Self

pub const fn add_min(&self, min: i64) -> Self

pub const fn add_hr(&self, hr: i64) -> Self

pub const fn yr(&self) -> i64

pub const fn mo(&self) -> u8

pub const fn day(&self) -> u8

pub const fn hr(&self) -> u8

pub const fn min(&self) -> u8

pub const fn sec(&self) -> u8

pub const fn attos(&self) -> u64

pub const fn unix_attosec(&self) -> i128

Attoseconds since 1970-01-01 midnight, on whatever time scale the object was created on.

pub const fn scale(&self) -> Scale

The time scale that the object was created on.