Module tzdb

Module tzdb 

This module is auto-generated from the IANA Time Zone Database found at: https://www.iana.org/time-zones Source directory: tzdata2026a It provides both a minimal mode (UTC + identical zones only) and a full mode (tz feature) which has full historical transitions. Generator source: https://github.com/ragardner/tz-info-generator-rs

Structs

OffsetInfo
Transition

Enums

Repeating
Repeating describes how (or if) the transition pattern continues indefinitely after the last explicit entry in the transitions slice.

Statics

ABBREVS
VERSION

Functions

abbrev
Returns the abbreviation string for the given index into ABBREVS.
get_tz_data
Returns the transition data for the given IANA timezone name.
offset_at_utc
Returns the offset (in seconds) for an IANA timezone at the given UTC Unix time.
offset_info_at_local
Returns offset information for an IANA timezone at the given local Unix time.
offset_info_at_utc
Returns offset information for an IANA timezone at the given UTC Unix time.