Repeating

Enum Repeating 

pub enum Repeating {
    None,
    Cycle {
        start: usize,
        len: usize,
        period: i64,
    },
}
Repeating describes how (or if) the transition pattern continues indefinitely after the last explicit entry in the transitions slice.

Variants



None



Cycle

The pattern repeats every period seconds starting at index start. len is the number of entries in one repeating unit (usually 2).

Fields

start: usize
len: usize
period: i64