get_tz_data

Function get_tz_data 

pub fn get_tz_data(
    name: &str,
) -> Option<(&str, &'static [Transition], Repeating)>
Returns the transition data for the given IANA timezone name.

Returns Some((name, transitions, repeating)) or None if unknown. repeating indicates whether (and how) the transition pattern repeats indefinitely for zones with perpetual DST rules.

For zones with Repeating::Cycle, the transitions slice contains only historical data + one copy of the repeating cycle (not many repetitions). The Cycle variant tells the runtime how to use it.