pub enum IsLeapSec {
None,
Add,
Sub,
}Expand description
Indicates whether a queried instant falls exactly on a leap second transition.
This is returned by LeapInfo::is_leap_sec and is only ever set to a
non-None value when the queried timestamp is exactly at the moment
a leap second is inserted or removed.
IsLeapSec::Addis returned for the inserted leap second (e.g.23:59:60).IsLeapSec::Subis returned for a negative (subtracted) leap second.IsLeapSec::Noneis returned for all normal seconds.
Variants
None
This instant is not a leap second.
Add
This instant is a positive leap second (a second is being inserted).
Example: 2015-06-30 23:59:60 UTC.
Sub
This instant is a negative leap second (a second is being removed).
Perhaps this would work by having clocks skip the 59th second of a
minute, e.g. 2015-06-30 23:59:58 UTC → 2015-07-01 00:00:00 UTC.