Leap seconds table from the official IANA
leap-seconds.list
Updated through IERS Bulletin C as of April 2026.
Last leap second: 2017-01-01 (TAI-UTC = 37 s)
File expires: 28 December 2026
This module is auto-generated from the IANA Time Zone Database
found at: https://www.iana.org/time-zones
Source directory: tzdata2026a
It provides both a minimal mode (UTC + identical zones only) and a full
mode (tz feature) which has full historical transitions.
Generator source: https://github.com/ragardner/tz-info-generator-rs
Quadratic polynomial that describes the accumulated difference between an
observer’s proper time (the time measured by a real clock moving through
spacetime) and a chosen coordinate time such as TT, TAI, or any other
Scale.
Dt, and the library, is in the process of being switched from the sec
and subsec fields being related to the scale, TO the sec and subsec fields
always being TAI Epoch 2000-01-01 noon.
Much of the documentation is outdated and should be ignored.