Module eop

Module eop 

Earth Orientation Parameters (EOP) data parser and interpolator.

Loads UT1–UTC offsets and polar motion (x, y) from standard IERS formats (Finals2000A, C04) or custom column layouts.

Provides interpolation at any MJD and integrates with Dt for UT1 time scale conversions.

Tries to be planet/body agnostic, such that custom data for any world might be able to be loaded and used.

Structs

CustomEopCols
For use with EopFormat.
EopData
Container for Body Orientation Parameters data.
EopDataRow
EopOffset
Interpolated Body Orientation Parameters at a specific MJD.

Enums

EopFormat
Body Orientation Parameters Format.
Separator