pub struct EopData { /* private fields */ }Expand description
Container for Body Orientation Parameters data.
- On Earth this would enable time scale conversions to and from the UT1 time scale.
- Earth Orientation Parameters data is available from: https://maia.usno.navy.mil/ser7/finals2000A.all
Implementations
Sourceimpl EopData
impl EopData
pub fn data_from_reader<R: BufRead>( reader: R, format: EopFormat, separator: Separator, ) -> Result<Vec<EopDataRow>, DtErr>
pub fn data_from_text_file<P: AsRef<Path>>( path: P, format: EopFormat, separator: Separator, ) -> Result<Vec<EopDataRow>, DtErr>
pub fn from_text_file<P: AsRef<Path>>( path: P, format: EopFormat, separator: Separator, ) -> Result<Self, DtErr>
Sourceimpl EopData
impl EopData
pub const MAX_LINE_LEN: usize = 8192
pub fn data_from_str( s: &str, format: EopFormat, separator: Separator, ) -> Result<Vec<EopDataRow>, DtErr>
pub fn data_from_bytes( bytes: &[u8], format: EopFormat, separator: Separator, ) -> Result<Vec<EopDataRow>, DtErr>
pub fn from_str( s: &str, format: EopFormat, separator: Separator, ) -> Result<Self, DtErr>
pub fn from_bytes( bytes: &[u8], format: EopFormat, separator: Separator, ) -> Result<Self, DtErr>
Sourcepub fn eop_offset(&self, mjd: Real) -> Option<EopOffset>
pub fn eop_offset(&self, mjd: Real) -> Option<EopOffset>
Returns all interpolated orientation parameters (offset + polar motion) at the given MJD.
Returns None if the table is empty or the MJD is completely outside
the loaded data.