Module drift

Module drift 

Quadratic polynomial for relativistic corrections, clock drift, and custom timescale steering.

Used to model the accumulated difference between Proper time (τ) and a coordinate time such as TT (or any other Scale).

Information on the underlying physical model (the master Lagrangian, different regimes of behavior, and its relationship to general relativity) can be found here.

Structs

Drift
Quadratic polynomial that describes the accumulated difference between an observer’s proper time (the time measured by a real clock moving through spacetime) and a chosen coordinate time such as TT, TAI, or any other Scale.