pub struct Every { /* private fields */ }Expand description
Implementations
Sourceimpl Every
impl Every
Sourcepub fn until(self, end: Dt) -> TimeRange ⓘ
pub fn until(self, end: Dt) -> TimeRange ⓘ
Creates an inclusive time range (start ... end).
The resulting iterator will yield end as the final element
(provided end is reachable from start with the given step).