StrPTimeFmt

Struct StrPTimeFmt 

pub struct StrPTimeFmt { /* private fields */ }
A pre-validated, reusable date/time format string.

  • Format is validated once at construction (new returns Result).
  • Format bytes are copied into an owned fixed-size buffer.
  • Only ASCII formats are accepted.

See also

Implementations

Source

impl StrPTimeFmt

pub const MAX_FORMAT_LEN: usize = 256

pub fn new(fmt: &str) -> Result<Self, DtErr>

Creates a new validated format.

  • Validates syntax and supported directives.
  • Requires the format to be valid ASCII and ≤ 256 bytes.
  • Returns a DtErr on any failure.
Examples
use deep_time::{Dt, StrPTimeFmt};

let fmt = Dt::parse_fmt("%F %T").unwrap();

// parse a datetime
let dt = fmt.to_dt("2025-05-23 14:30:00", false, false, false).unwrap();

// change a datetimes format
let s = fmt.to_str("2000-01-01 12:00:00", "%d %m %Y %H:%M:%S", false, false, false).unwrap();
pub fn to_dt( &self, s: &str, inp_can_end_before_fmt: bool, fmt_can_end_before_inp: bool, allow_partial_date: bool, ) -> Result<Dt, DtErr>

Parses a date/time string using this pre-validated format.

The four boolean flags control lenient parsing behavior — see Dt::from_str for full documentation.

Parameters
  • s: The input string to parse.
  • inp_can_end_before_fmt: Allow input to end before format is fully consumed.
  • fmt_can_end_before_inp: Allow format to end before input is fully consumed.
  • allow_partial_date: Default missing month/day to 1 instead of erroring.
Errors

Returns DtErr for parse failures, incomplete data, trailing characters, etc.

Example
use deep_time::{Dt, StrPTimeFmt};

let fmt = Dt::parse_fmt("%F %T").unwrap();
let dt = fmt.to_dt("2025-05-23 14:30:00", false, false, false).unwrap();
pub fn to_str( &self, s: &str, output_fmt: &str, inp_can_end_before_fmt: bool, fmt_can_end_before_inp: bool, allow_partial_date: bool, ) -> Result<String, DtErr>

Formats a Dt into a string using this pre-validated format and a given output format.

Effectively parses a [str] with the contained format, then outputs a String to a new given format.

Requires the alloc feature.

Parameters
  • s: datetime input [str].
  • output_fmt: The new format to output the datetime as.
  • The remaining three flags are passed through to the internal to_dt call.
Example
use deep_time::{Dt, StrPTimeFmt};

let fmt = Dt::parse_fmt("%Y-%m-%dT%H:%M:%S").unwrap();
let s = fmt.to_str("2000-01-01T12:00:00", "%d %m %Y %H:%M:%S", false, false, false).unwrap();