pub struct YmdHms { /* private fields */ }Expand description
Combined date + time object.
Has calendar aware and, when the jiff-tz feature is enabled,
timezone aware math functions.
Examples
Creating a YmdHms.
use deep_time::{Dt, Scale};
// clamped to 29
let x = Dt::from_ymd(2000, 2, 30, Scale::UTC, 0, 0, 0, 0).to_ymd();
assert_eq!(x.day(), 29);Adding a year. 2000 is a leap year and Feb. 29th is possible, but 2001 isn’t a leap year so the day is clamped to the 28th.
use deep_time::{Dt, Scale};
let x = Dt::from_ymd(2000, 2, 29, Scale::UTC, 0, 0, 0, 0).to_ymd();
let x = x.add_yr(1);
assert_eq!(x.day(), 28);Implementations
Sourceimpl YmdHms
impl YmdHms
Sourcepub const fn new(
yr: i64,
mo: u8,
day: u8,
scale: Scale,
hr: u8,
min: u8,
sec: u8,
attos: u64,
) -> YmdHms
pub const fn new( yr: i64, mo: u8, day: u8, scale: Scale, hr: u8, min: u8, sec: u8, attos: u64, ) -> YmdHms
Create a new YmdHms, wrapper around
Dt::from_ymd.
Sourcepub const fn add_yr(&self, n: i64) -> Self
pub const fn add_yr(&self, n: i64) -> Self
Adds (or subtracts) whole years, preserving month and day-of-month.
- Uses standard last-day-of-month clamping.
- Negative values subtract.
Sourcepub const fn add_mo(&self, n: i64) -> Self
pub const fn add_mo(&self, n: i64) -> Self
Adds (or subtracts) calendar months. Negative values subtract.
Sourcepub const fn add_wk(&self, n: i64) -> Self
pub const fn add_wk(&self, n: i64) -> Self
Adds (or subtracts) calendar weeks. Negative values subtract.
Sourcepub const fn add_days(&self, n: i64) -> Self
pub const fn add_days(&self, n: i64) -> Self
Adds (or subtracts) calendar days. Negative values subtract.
Sourcepub const fn add_attos(&self, n: i128) -> Self
pub const fn add_attos(&self, n: i128) -> Self
Adds (or subtracts) attoseconds. Negative values subtract.
Sourcepub const fn add_sec(&self, n: i64) -> Self
pub const fn add_sec(&self, n: i64) -> Self
Adds (or subtracts) whole seconds. Negative values subtract.
Sourcepub const fn add_min(&self, n: i64) -> Self
pub const fn add_min(&self, n: i64) -> Self
Adds (or subtracts) whole minutes. Negative values subtract.
Sourcepub const fn add_hr(&self, n: i64) -> Self
pub const fn add_hr(&self, n: i64) -> Self
Adds (or subtracts) whole hours. Negative values subtract.
Sourcepub const fn day(&self) -> u8
pub const fn day(&self) -> u8
Returns the day-of-month component (1–31, depending on month/year).
Sourcepub const fn sec(&self) -> u8
pub const fn sec(&self) -> u8
Returns the second component (0–60). The value 60 only occurs during
a positive leap second on Scale::UTC / UtcSpice / UtcHist.
Sourcepub const fn attos(&self) -> u64
pub const fn attos(&self) -> u64
Returns the attosecond (sub-second) component (0 ≤ attos < 10¹⁸).
Sourcepub const fn time_scale(&self) -> Scale
pub const fn time_scale(&self) -> Scale
The time scale that the object was created on.
Sourcepub const fn iso_yr(&self) -> i64
pub const fn iso_yr(&self) -> i64
Returns the ISO week year (can differ from the calendar year near January 1 / December 31).
Sourcepub const fn iso_wk(&self) -> u8
pub const fn iso_wk(&self) -> u8
Returns the ISO week number (1–53). Weeks start on Monday; week 1 is the week containing the first Thursday of the year.
Sourcepub const fn day_of_yr(&self) -> u16
pub const fn day_of_yr(&self) -> u16
Returns the day of the year (ordinal date), 1-based (Jan 1 = 1, Dec 31 = 365 or 366 in leap years).
Sourcepub const fn wkday(&self) -> u8
pub const fn wkday(&self) -> u8
Returns the weekday number according to Dt::jd_to_wkday
(typically 0 = Sunday … 6 = Saturday; exact convention is defined
by the Julian Day helper).
Sourcepub const fn wk_of_yr_sun(&self) -> u8
pub const fn wk_of_yr_sun(&self) -> u8
Returns the week of year number when weeks are considered to start on Sunday (US-style numbering).
Sourcepub const fn wk_of_yr_mon(&self) -> u8
pub const fn wk_of_yr_mon(&self) -> u8
Returns the week of year number when weeks are considered to start on Monday.
Sourceimpl YmdHms
impl YmdHms
Sourcepub fn add_yr_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_yr_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of years in the specified IANA timezone, respecting timezone rules (including DST) and proper calendar arithmetic.
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_mo_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_mo_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of months in the specified IANA timezone, respecting timezone rules and calendar month-end clamping.
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_wk_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_wk_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of weeks in the specified IANA timezone.
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_days_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_days_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of calendar days in the specified IANA timezone.
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_hr_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_hr_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of hours in the specified IANA timezone, respecting timezone rules (including DST).
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_min_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_min_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of minutes in the specified IANA timezone, respecting timezone rules (including DST).
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).
Sourcepub fn add_sec_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
pub fn add_sec_tz(&self, n: i64, tz: &str) -> Result<Self, DtErr>
Adds the given number of seconds in the specified IANA timezone.
Errors
DtErrKind::YearOutOfRangeif the year of the date is outside the-9999..=9999range (checked before involving Jiff).- Specific errors for invalid time components when preparing values for Jiff:
DtErrKind::InvalidHour,DtErrKind::InvalidMinute,DtErrKind::InvalidSecond,DtErrKind::InvalidMonth, orDtErrKind::InvalidDay. DtErrKind::InvalidTimeZoneif Jiff cannot find/resolve the IANA timezone name.DtErrKind::OutOfRangeif the result of the calendar arithmetic operation would be outside the range supported by Jiff (the checked_add fails).